@@ -17,17 +17,19 @@
 #' @references \url{https://developer.clarifai.com/}
 #' 
 #' @examples \dontrun{
+#' 
+#' # Before calling the function, set API secret and id via secret_id(c("client_id", "secret")) 
+#' # and get token via get_token()
+#' 
 #' get_color_urls("https://samples.clarifai.com/metro-north.jpg")
 #' get_color_urls(c("https://samples.clarifai.com/metro-north.jpg", 
 #' 					"https://samples.clarifai.com/metro-north.jpg"))
 #' }
 
-get_color_urls <- function(img_urls=NULL, meta=FALSE, ...) {
+get_color_urls <- function(img_urls = NULL, meta = FALSE, ...) {
 
 	if (is.null(img_urls)) stop("Please specify a valid image url.", call. = FALSE)
-
-	clarifai_check_token()
-    
+	    
     query <- as.list(img_urls)
     names(query) <- rep("url", length(query))
 
@@ -35,11 +37,11 @@ get_color_urls <- function(img_urls=NULL, meta=FALSE, ...) {
 
 	if (color$status_code!="OK") {
 		print(color$status)
-		return(invisible(list()))
+		return(list())
 	}
 
-	if (!meta) return(invisible(color$results))
+	if (!meta) return(color$results)
 
-	return(invisible(color))
+	color
 
 }
\ No newline at end of file
