@@ -21,50 +21,49 @@
 #' for each image
 #' 
 #' @export
+#' 
 #' @references \url{https://developer.clarifai.com/}
+#' 
 #' @seealso \code{\link{tag_image_urls}}
+#' 
 #' @examples \dontrun{
+#' 
+#' # Before calling the function, set API secret and id via secret_id(c("client_id", "secret")) 
+#' # and get token via get_token()
+#' 
 #' tag_images(file_paths="path_to_image")
 #' }
 
 
-tag_images <- function(file_paths=NULL, model=NULL, language = NULL, meta=FALSE, simplify=TRUE, ...) {
-	
-    clarifai_check_token()
-        
-    if (! all(file.exists(file_paths))) stop("File Doesn't Exist. Please check the path.", call. = FALSE)
+tag_images <- function(file_paths = NULL, model = NULL, language = NULL, meta = FALSE, simplify = TRUE, ...) {
+	        
+    if (! all(file.exists(file_paths))) stop("At least one of the Files Doesn't Exist. Please check the path.", call. = FALSE)
 
-    query <- lapply(file_paths, form_file)
+    query        <- lapply(file_paths, form_file)
 	names(query) <- rep("encoded_image", length(query))
-	query$model <- model
-	query$language <- language
+	query        <- c(query, model = model, language = language)
 
-	if (is.null(model)) {    
-		tag <- clarifai_POST(path="tag/", query, ...)
-	} else {
-		query$model <- model
-		tag <- clarifai_POST(path="tag/", query, ...)
-	}
+	tag <- clarifai_POST(path="tag/", query, ...)
 
 	if (identical(meta, FALSE)) {
 		
 		if (identical(simplify, TRUE)) {
         
-		   tags  <- lapply(tag$results$result$tag$classes, unlist)
-		   concept_ids <- lapply(tag$results$result$tag$concept_ids, unlist)
-		   probs <- lapply(tag$results$result$tag$probs, unlist)
-		   tags_probs <- do.call(rbind, Map(cbind, tags, probs, concept_ids))
-		   len <- sapply(probs, length)
-		   tags_probs_imgs <- data.frame(file_paths=rep(file_paths, len), tags_probs)
+		   tags            <- lapply(tag$results$result$tag$classes, unlist)
+		   concept_ids     <- lapply(tag$results$result$tag$concept_ids, unlist)
+		   probs           <- lapply(tag$results$result$tag$probs, unlist)
+		   tags_probs      <- do.call(rbind, Map(cbind, tags, probs, concept_ids))
+		   len             <- sapply(probs, length)
+		   tags_probs_imgs <- data.frame(file_paths = rep(file_paths, len), tags_probs)
 		   names(tags_probs_imgs) <- c("file_paths", "tags", "probs", "concept_ids")
-		   return(invisible(tags_probs_imgs))
+		   return(tags_probs_imgs)
 		}
 
-		return(invisible(tag$results$result$tag))
+		return(tag$results$result$tag)
 
 	}
 
-	return(invisible(tag))
+	tag
 
 }
 
